@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -89,6 +89,33 @@ def _clusterize(hits, model, hit_weights, rep_info):
     :return: the clusters
     :rtype: list of :class:`macsypy.cluster.Cluster` objects.
     """
+    def do_clst(cluster_scaffold, model, hit_weights):
+        """
+
+        :param cluster_scaffold:
+        :param model:
+        :param hit_weights:
+        :return:
+        """
+        gene_types = {hit.gene_ref.name for hit in cluster_scaffold}
+        if len(gene_types) > 1:
+            if all([_hit.gene_ref.status == GeneStatus.NEUTRAL for _hit in cluster_scaffold]):
+                # we do not consider a group of neutral as a cluster
+                _log.debug(f"({', '.join([h.id for h in cluster_scaffold])}) "
+                           f"is composed of only neutral. It's not a cluster.")
+            else:
+                cluster = Cluster(cluster_scaffold, model, hit_weights)
+                clusters.append(cluster)
+        else:
+            cluster = Cluster(cluster_scaffold, model, hit_weights)
+            if cluster.loner:
+                # it's a group of one loner add as cluster
+                # it will be squashed at  next step (_get_true_loners )
+                clusters.append(cluster)
+            else:
+                _log.debug(f"({', '.join([h.id for h in cluster_scaffold])}) "
+                           f"is composed of only type of gene {cluster_scaffold[0].gene_ref.name}. It's not a cluster.")
+
     clusters = []
     cluster_scaffold = []
     # sort hits by increasing position and then descending score
@@ -108,20 +135,17 @@ def _clusterize(hits, model, hit_weights, rep_info):
             else:
                 if len(cluster_scaffold) > 1:
                     # close the current scaffold if it contains at least 2 hits
-                    cluster = Cluster(cluster_scaffold, model, hit_weights)
-                    clusters.append(cluster)
+                    do_clst(cluster_scaffold, model, hit_weights)
                 elif model.min_genes_required == 1:
                     # close the current scaffold if it contains 1 hit
                     # but it's allowed by the model
                     cluster = Cluster(cluster_scaffold, model, hit_weights)
                     clusters.append(cluster)
                 elif model.get_gene(cluster_scaffold[0].gene.name).loner:
-                    # close the current scaffold it contains 1 hit
-                    # to handle circularity if it's the last cluster
+                    # close the current scaffold it contains 1 hit but the model gene is tag as  a loner
                     cluster = Cluster(cluster_scaffold, model, hit_weights)
                     clusters.append(cluster)
-                    # the hit transformation in loner is perform at the end when
-                    # circularity and merging is done
+                    # the hit transformation in loner is performed at the end when circularity and merging is done
 
                 # open new scaffold
                 cluster_scaffold = [m_hit]
@@ -130,8 +154,7 @@ def _clusterize(hits, model, hit_weights, rep_info):
         # close the last current cluster
         len_scaffold = len(cluster_scaffold)
         if len_scaffold > 1:
-            new_cluster = Cluster(cluster_scaffold, model, hit_weights)
-            clusters.append(new_cluster)
+            do_clst(cluster_scaffold, model, hit_weights)
         elif len_scaffold == 1:
             # handle circularity
             # if there are clusters
@@ -140,7 +163,7 @@ def _clusterize(hits, model, hit_weights, rep_info):
                 new_cluster = Cluster(cluster_scaffold, model, hit_weights)
                 clusters[0].merge(new_cluster, before=True)
             elif cluster_scaffold[0].gene_ref.loner:
-                # the hit does not collocate but it's a loner
+                # the hit does not collocate, but it's a loner
                 # handle clusters containing only one loner
                 new_cluster = Cluster(cluster_scaffold, model, hit_weights)
                 clusters.append(new_cluster)
@@ -160,7 +183,7 @@ def _clusterize(hits, model, hit_weights, rep_info):
 
 def _get_true_loners(clusters):
     """
-    A we call a True Loner a Cluster composed of only one gene tagged as loner
+    We call a True Loner a Cluster composed of one or several hit related to the same gene tagged as loner
     (by opposition with hit representing a gene tagged loner but include in cluster with several other genes)
 
     :param clusters: the clusters
@@ -170,6 +193,18 @@ def _get_true_loners(clusters):
              * dict containing true clusters  {str func_name : :class:`macsypy.hit.Loner | :class:`macsypy.hit.LonerMultiSystem` object}
              * list of :class:`macsypy.cluster.Cluster` objects
     """
+    def add_true_loner(clstr):
+        hits = clstr.hits
+        clstr_len = len(hits)
+        if clstr_len > 1:
+            _log.warning(f"Squash cluster of {clstr_len} {clstr[0].gene_ref.name} loners "
+                         f"({hits[0].position} -> {hits[-1].position})")
+        func_name = clstr[0].gene_ref.alternate_of().name
+        if func_name in true_loners:
+            true_loners[func_name].extend(hits)
+        else:
+            true_loners[func_name] = hits
+
     ###################
     # get True Loners #
     ###################
@@ -181,15 +216,9 @@ def _get_true_loners(clusters):
         model = clusters[0].model
         hit_weights = clusters[0].hit_weights
         for clstr in clusters:
-            if len(clstr) > 1:
-                true_clusters.append(clstr)
-            elif clstr.loner:
-                loner = clstr[0]
-                func_name = loner.gene_ref.alternate_of().name
-                if func_name in true_loners:
-                    true_loners[func_name].append(loner)
-                else:
-                    true_loners[func_name] = [loner]
+            if clstr.loner:
+                # it's  a true Loner or a stretch of same loner
+                add_true_loner(clstr)
             else:
                 # it's a cluster of 1 hit
                 # but it's NOT a loner
@@ -298,20 +327,22 @@ class Cluster:
     @property
     def loner(self):
         """
-        :return: True if this cluster is made of only one hit representing a loner gene
+        :return: True if this cluster is made of only some hits representing the same gene and this gene is tag as loner
                  False otherwise:
-                 - contains several hits
+                 - contains several hits coding for different genes
                  - contains one hit but gene is not tag as loner (max_gene_required = 1)
         """
         # need this method in build_cluster before to transform ModelHit in Loner
         # so cannot rely on Loner type
-        return len(self) == 1 and self.hits[0].gene_ref.loner
+        # beware return True if several hits of same gene composed this cluster
+        return len({h.gene_ref.name for h in self.hits}) == 1 and self.hits[0].gene_ref.loner
 
     @property
     def multi_system(self):
         """
         :return: True if this cluster is made of only one hit representing a multi_system gene
                  False otherwise:
+
                  - contains several hits
                  - contains one hit but gene is not tag as loner (max_gene_required = 1)
         """
@@ -333,6 +364,7 @@ class Cluster:
 
     def __contains__(self, v_hit):
         """
+
         :param v_hit: The hit to test
         :type v_hit: :class:`macsypy.hit.ModelHit` object
         :return: True if the hit is in the cluster hits, False otherwise
@@ -340,6 +372,32 @@ class Cluster:
         return v_hit in self.hits
 
 
+    @property
+    def functions(self):
+        """
+
+        :return: The set of functions encoded by this cluster
+                 *function* mean gene name or reference gene name for exchangeables genes
+                 for instance
+
+                 <model vers="2.0">
+                     <gene a presence="mandatory"/>
+                     <gene b presence="accessory"/>
+                        <exchangeable>
+                            <gene c />
+                        </exchangeable>
+                     <gene/>
+                 </model>
+
+                 the functions for a cluster corresponding to this model wil be {'a' , 'b'}
+
+        :rtype: frozenset
+        """
+        if self._genes_roles is None:
+            self._genes_roles = frozenset({h.gene_ref.alternate_of().name for h in self.hits})
+        return self._genes_roles
+
+
     def fulfilled_function(self, *genes):
         """
 
@@ -349,8 +407,7 @@ class Cluster:
         :rtype: set of string
         """
         # we do not filter out neutral from the model
-        if self._genes_roles is None:
-            self._genes_roles = {h.gene_ref.alternate_of().name for h in self.hits}
+        genes_roles = self.functions
         functions = set()
         for gene in genes:
             if isinstance(gene, macsypy.gene.ModelGene):
@@ -359,7 +416,7 @@ class Cluster:
                 # gene is a string
                 function = gene
             functions.add(function)
-        return self._genes_roles.intersection(functions)
+        return genes_roles.intersection(functions)
 
 
     def merge(self, cluster, before=False):
