@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -27,6 +27,7 @@ Module to manage both default values and configuration needed by macsyfinder
 """
 
 import os
+import shutil
 from time import strftime
 import logging
 from configparser import ConfigParser, ParsingError
@@ -71,9 +72,9 @@ class MacsyDefaults(dict):
         self.cfg_file = kwargs.get('cfg_file', None)
         self.coverage_profile = kwargs.get('coverage_profile', 0.5)
         self.e_value_search = kwargs.get('e_value_search', 0.1)
-        self.no_cut_ga = kwargs.get('no_cut_ga', False)
+        self.cut_ga = kwargs.get('cut_ga', True)
         self.db_type = kwargs.get('db_type', None)
-        self.hmmer = kwargs.get('hmmer', 'hmmsearch')
+        self.hmmer = kwargs.get('hmmer', shutil.which('hmmsearch'))
         self.i_evalue_sel = kwargs.get('i_evalue_sel', 0.001)
         self.idx = kwargs.get('idx', False)
         self.index_dir = kwargs.get('index_dir', None)
@@ -113,7 +114,8 @@ class MacsyDefaults(dict):
         self.out_of_cluster_weight = kwargs.get('out_of_cluster_weight', .7)
         self.itself_weight = kwargs.get('itself_weight', 1.0)
         self.redundancy_penalty = kwargs.get('redundancy_penalty', 1.5)
-
+        self.timeout = kwargs.get('timeout', 0)
+        self.force_run = kwargs.get('force_run', False)
 
 
 class Config:
@@ -126,13 +128,13 @@ class Config:
                 ('models_opt', ('inter_gene_max_space', 'max_nb_genes', 'min_mandatory_genes_required',
                                 'min_genes_required', 'multi_loci')),
                 ('models', tuple()),
-                ('hmmer', ('coverage_profile', 'e_value_search', 'no_cut_ga', 'i_evalue_sel', 'hmmer')),
+                ('hmmer', ('coverage_profile', 'e_value_search', 'cut_ga', 'i_evalue_sel', 'hmmer')),
                 ('score_opt', ('mandatory_weight', 'accessory_weight', 'neutral_weight', 'exchangeable_weight',
                                'itself_weight', 'redundancy_penalty', 'out_of_cluster_weight')),
                 ('directories', ('models_dir', 'system_models_dir', 'out_dir', 'profile_suffix', 'res_search_dir',
                                  'res_search_suffix', 'res_extract_suffix', 'index_dir')),
                 ('general', ('cfg_file', 'log_file', 'log_level', 'previous_run', 'relative_path',
-                             'verbosity', 'quiet', 'mute', 'worker')),
+                             'verbosity', 'quiet', 'mute', 'worker', 'timeout', 'force_run')),
                 ]
 
     model_opts = ('itself', 'exchangeable', 'mandatory', 'accessory', 'neutral',
@@ -234,6 +236,13 @@ class Config:
         # by the values provided by previous-run, project conf, the users on the commandline
         self._options.update(self._tmp_opts)
 
+        # check that hmmsearch exists
+        if not self.hmmer():
+            msg = "'hmmsearch' NOT found in your PATH, Please specify hmmsearch path with --hmmer opt " \
+                  "or install 'hmmer' package."
+            _log.critical(msg)
+            raise ValueError(msg)
+
 
     def _set_options(self, options):
         """
@@ -328,6 +337,7 @@ class Config:
                 del user_config[opt]
         self._set_options(user_config)
 
+
     def _set_previous_run_config(self, prev_config_path):
         """
         Set the options specified by the user on the command line via --previous-run
@@ -773,6 +783,17 @@ class Config:
         self._options['log_level'] = self._convert_log_level(value)
 
 
+    def _set_no_cut_ga(self, value):
+        """
+
+        :param value:
+        :type value:
+        :return:
+        :rtype:
+        """
+        self._options['cut_ga'] = not value
+
+
     def models_dir(self):
         """
 
