@@ -25,7 +25,7 @@
 """
 Module to handle sequences and their indexes
 """
-
+import gzip
 from itertools import groupby
 from collections import namedtuple
 import os.path
@@ -194,8 +194,19 @@ class Indexes:
 
         """
         index_file = os.path.join(index_dir, self.name + ".idx")
+        _, ext = os.path.splitext(self._fasta_path)
+        if ext == '.gz':
+            my_open = gzip.open
+        elif ext == '.bz2' or ext == '.zip':
+            msg = f"MacSyFinder does not support '{ext[1:]}' compression (only gzip)."
+            _log.critical(msg)
+            raise ValueError(msg)
+        else:
+            # I assumed it's a fasta not compressed
+            my_open = open
+
         try:
-            with open(self._fasta_path, 'r') as fasta_file:
+            with my_open(self._fasta_path, 'rt') as fasta_file:
                 with open(index_file, 'w') as my_base:
                     my_base.write(self._fasta_path + '\n')
                     f_iter = fasta_iter(fasta_file)
