@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -31,12 +31,15 @@ import sys
 import os
 import argparse
 import shutil
-from textwrap import dedent
+import textwrap
+import time
 from typing import List, Tuple, Dict, Optional
 import pathlib
 import logging
+import xml.etree.ElementTree as ET
 
 import colorlog
+import yaml
 from packaging import requirements, specifiers, version
 
 import macsypy
@@ -44,6 +47,7 @@ from macsypy.error import MacsyDataLimitError
 from macsypy.config import MacsyDefaults, Config
 from macsypy.registries import ModelRegistry, ModelLocation, scan_models_dir
 from macsypy.package import RemoteModelIndex, LocalModelIndex, Package, parse_arch_path
+from macsypy import licenses
 
 # _log is set in main func
 _log = None
@@ -246,10 +250,20 @@ def do_install(args: argparse.Namespace) -> None:
     :rtype: None
     """
     def clean_cache(model_index):
+        if args.no_clean:
+            _log.debug(f"skip cleaning {model_index.cache}")
+            return
         try:
             shutil.rmtree(model_index.cache)
         except Exception:
             _log.warning(f"Cannot clean cache '{model_index.cache}': {err}")
+    def create_dir(path):
+        if os.path.exists(path) and not os.path.isdir(path):
+            clean_cache(model_index)
+            raise RuntimeError(f"'{path}' already exist and is not a directory.")
+        elif not os.path.exists(path):
+            os.makedirs(path)
+        return path
 
     if os.path.exists(args.package):
         remote = False
@@ -343,18 +357,16 @@ def do_install(args: argparse.Namespace) -> None:
 
     _log.info(f"Extracting {pack_name} ({target_vers}).")
     cached_pack = model_index.unarchive_package(arch_path)
+    _log.debug(f"package is chached at {cached_pack}")
 
     if args.user:
         dest = os.path.realpath(os.path.join(os.path.expanduser('~'), '.macsyfinder', 'models'))
-        if os.path.exists(dest) and not os.path.isdir(dest):
-            clean_cache(model_index)
-            raise RuntimeError("'{}' already exist and is not a directory.")
-        elif not os.path.exists(dest):
-            os.makedirs(dest)
+        create_dir(dest)
     elif args.target:
         dest = args.target
     elif 'VIRTUAL_ENV' in os.environ:
         dest = os.path.join(os.environ['VIRTUAL_ENV'], 'share', 'macsyfinder', 'models')
+        create_dir(dest)
     else:
         defaults = MacsyDefaults()
         config = Config(defaults, argparse.Namespace())
@@ -381,6 +393,7 @@ for the system wide models installation please refer to the documentation.
 
     _log.info(f"Installing {pack_name} ({target_vers}) in {dest}")
     try:
+        _log.debug(f"move {cached_pack} -> {dest}")
         shutil.move(cached_pack, dest)
     except PermissionError as err:
         clean_cache(model_index)
@@ -460,17 +473,18 @@ def do_list(args: argparse.Namespace) -> None:
         try:
             pack = Package(model_loc.path)
             pack_vers = pack.metadata['vers']
+            model_path = f"   ({model_loc.path})" if args.long else ""
             if args.outdated or args.uptodate:
                 remote = RemoteModelIndex(org=args.org)
                 all_versions = remote.list_package_vers(pack.name)
                 specifier = specifiers.SpecifierSet(f">{pack_vers}")
                 update_vers = list(specifier.filter(all_versions))
                 if args.outdated and update_vers:
-                    print(f"{model_loc.name}-{update_vers[0]} [{pack_vers}]")
+                    print(f"{model_loc.name}-{update_vers[0]} [{pack_vers}]{model_path}")
                 if args.uptodate and not update_vers:
-                    print(f"{model_loc.name}-{pack_vers}")
+                    print(f"{model_loc.name}-{pack_vers}{model_path}")
             else:
-                print(f"{model_loc.name}-{pack_vers}")
+                print(f"{model_loc.name}-{pack_vers}{model_path}")
         except Exception as err:
             if args.verbose > 1:
                 _log.warning(str(err))
@@ -646,6 +660,323 @@ def do_show_definition(args: argparse.Namespace) -> None:
         raise ValueError() from None
 
 
+def do_init_package(args: argparse.Namespace) -> None:
+    """
+    Create a template for data package
+
+        - skeleton for metadata.yml
+        - definitions directory with a skeleton of models.xml
+        - profiles directory
+        - skeleton for README.md file
+        - COPYRIGHT file (if holders option is set)
+        - LICENSE file (if license option is set)
+
+    :param args: The parsed commandline subcommand arguments
+    :return: None
+    """
+
+    def create_package_dir(package_name: str, models_dir: str = None) -> str:
+        """
+
+        :param str package_name:
+        :param models_dir: the path where to create the new package
+        :return: the path of the package directory
+        :rtype: str
+        """
+        pack_path = package_name if not models_dir else os.path.join(models_dir, package_name)
+        if not os.path.exists(pack_path):
+            os.makedirs(pack_path)
+        else:
+            raise ValueError(f"{pack_path} already exist.")
+        return pack_path
+
+    def add_metadata(pack_dir: str, maintainer: str, email: str,
+                     desc: str = None, license: str = None,
+                     c_date: str = None, c_holders: str = None) -> None:
+        """
+
+        :param pack_dir: the package directory path
+        :param maintainer: the maintainer name
+        :param email: the maintainer email
+        :param desc: a One line description of the package
+        :param license: the license choosed
+        :param c_date: the date of the copyright
+        :param c_holders: the holders of the copyright
+        :return: None
+        """
+        metadata = {
+            'maintainer': {
+                'name': maintainer,
+                'email': email
+            },
+            'short_desc': desc,
+            'cite': 'Place here how to cite this package, it can hold several citation',
+            'doc': 'where to find documentation about this package',
+            'vers': '0.1b1',
+        }
+
+        if copyright:
+            metadata['copyright'] = f"Copyright (c) {c_date} {c_holders}"
+
+        if license:
+            metadata['license'] = licenses.name_2_url(license)
+
+        with open(os.path.join(pack_dir, 'metadata.yml'), 'w') as metafile:
+            yaml.dump(metadata, metafile)
+
+
+    def add_def_skeleton(license: str =None) -> None:
+        """
+        Create a example of model definition
+
+        :param license: the text of the license
+        :return: None
+        """
+        model = ET.Element('model',
+                           attrib={'inter_gene_max_space': "5",
+                                   'min_mandatory_genes_required': "2",
+                                   'min_genes_required': "3",
+                                   'vers': "2.0"
+                                   }
+        )
+        comment = ET.Comment('GENE_1 is a mandatory gene. GENE_1.hmm must exist in profiles directory')
+        model.append(comment)
+        mandatory = ET.SubElement(model, 'gene',
+                                  attrib={'name': 'GENE_1',
+                                          'presence': 'mandatory'})
+        comment = ET.Comment("GENE_2 is accessory and can be exchanged with GENE_3 which play a similar role in model.\n"
+                             "Both GENE_2.hmm and GENE_3.hmm must exist in profiles_directory")
+        model.append(comment)
+        accessory = ET.SubElement(model, 'gene',
+                                  attrib={'name': 'GENE_2',
+                                          'presence': 'accessory',
+                                          })
+        exchangeables = ET.SubElement(accessory, 'exchangeables')
+        ex_gene = ET.SubElement(exchangeables, 'gene',
+                                attrib={'name': 'GENE_3'})
+        comment = ET.Comment("GENE_4 can be anywhere in the genome and not clusterized with some other model genes")
+        model.append(comment)
+        loner = ET.SubElement(model, 'gene',
+                              attrib={'name': 'GENE_4',
+                                      'presence': 'accessory',
+                                      'loner': 'true'}
+                              )
+        comment = ET.Comment("GENE_5 can be shared by several systems instance from different models.")
+        model.append(comment)
+        multi_model = ET.SubElement(model, 'gene',
+                                    attrib={'name': 'GENE_5',
+                                            'presence': 'accessory',
+                                            'multi_model': 'true'}
+                              )
+        comment = ET.Comment("GENE_6 have specific clusterisation rule")
+        model.append(comment)
+        inter = ET.SubElement(model, 'gene',
+                              attrib={'name': 'GENE_6',
+                                      'presence': 'accessory',
+                                      'inter_gene_max_space': '10'}
+                              )
+        comment = ET.Comment("\nFor exhaustive documentation about grammar visit \n"
+                             "https://macsyfinder.readthedocs.io/en/latest/modeler_guide/package.html\n")
+        model.append(comment)
+        tree = ET.ElementTree(model)
+        try:
+            ET.indent(model)
+        except AttributeError:
+            # workaround as ET.indent appear in python3.9
+            from macsypy.utils import indent_wrapper
+            ET.indent = indent_wrapper(type(tree))
+            ET.indent(model)
+
+        def_path = os.path.join(pack_dir, 'definitions', 'model_example.xml')
+        tree.write(def_path,
+                   encoding='UTF-8',
+                   xml_declaration=True)
+
+        if license:
+            # Elementtree API does not allow to insert comment outside the tree (before root node)
+            # this is the reason of this workaround
+            # write the xml, read it as text, insert the comment, and write it again :-(
+            with open(def_path, 'r') as def_file:
+                definition = def_file.readlines()
+            license = f"""<!--
+{license}-->
+"""
+            definition.insert(1, license)
+            with open(def_path, 'w') as def_path:
+                def_path.writelines(definition)
+
+
+    def add_license(pack_dir: str, license_text: str):
+        """
+        Create a license file
+
+        :param pack_dir: the package directory path
+        :param license_text: the text of the license
+        :return: None
+        """
+        with open(os.path.join(pack_dir, 'LICENSE'), 'w') as license_file:
+            license_file.write(license_text)
+
+
+    def add_copyright(pack_dir: str, pack_name: str, date: str, holders: str, desc: str):
+        """
+
+        :param str pack_dir: The path of package directory
+        :param str pack_name: The name of the package
+        :param str date: The date (year) of package creation
+        :param str holders: The copyright holders
+        :param str desc: One line description of the package
+        :return: None
+        """
+        desc = desc if desc is not None else ''
+        head = textwrap.fill(f"{pack_name} - {desc}")
+        text = f"""{head}
+        
+Copyright (c) {date} {holders}        
+"""
+        with open(os.path.join(pack_dir, 'COPYRIGHT'), 'w') as copyright_file:
+            copyright_file.write(text)
+
+
+    def add_readme(pack_dir: str, pack_name: str, desc: str):
+        """
+
+        :param str pack_dir: The path of package directory
+        :param str pack_name: The name of the package
+        :param str desc: One line description of the package
+        :return: None
+        """
+        desc = desc if desc is not None else ''
+        text = f"""
+# {pack_name}: {desc}
+
+Place here information about {pack_name}
+
+- how to use it
+- how to cite it
+- ...
+
+using markdown syntax
+https://docs.github.com/en/get-started/writing-on-github/getting-started-with-writing-and-formatting-on-github/basic-writing-and-formatting-syntax
+"""
+        with open(os.path.join(pack_dir, 'README.md'), 'w') as readme_file:
+            readme_file.write(text)
+
+
+    def create_model_conf(pack_dir: str, license: str = None):
+        """
+
+        :param pack_dir: The path of the package directory
+        :param license: The text of the chosen license
+        :return: None
+        """
+        msf_defaults = MacsyDefaults()
+        model_conf = ET.Element('model_config')
+
+        weights = ET.SubElement(model_conf, 'weights')
+        mandatory = ET.SubElement(weights, 'mandatory')
+        mandatory.text = str(msf_defaults['mandatory_weight'])
+        accessory = ET.SubElement(weights, 'accessory')
+        accessory.text = str(msf_defaults['accessory_weight'])
+        exchangeable = ET.SubElement(weights, 'exchangeable')
+        exchangeable.text = str(msf_defaults['exchangeable_weight'])
+        redundancy_penalty = ET.SubElement(weights, 'redundancy_penalty')
+        redundancy_penalty.text = str(msf_defaults['redundancy_penalty'])
+        out_of_cluster = ET.SubElement(weights, 'out_of_cluster')
+        out_of_cluster.text = str(msf_defaults['out_of_cluster_weight'])
+
+        filtering = ET.SubElement(model_conf, 'filtering')
+        e_value_search = ET.SubElement(filtering, 'e_value_search')
+        e_value_search.text = str(msf_defaults['e_value_search'])
+        i_evalue_sel = ET.SubElement(filtering, 'i_evalue_sel')
+        i_evalue_sel.text = str(msf_defaults['i_evalue_sel'])
+        coverage_profile = ET.SubElement(filtering, 'coverage_profile')
+        coverage_profile.text = str(msf_defaults['coverage_profile'])
+        cut_ga = ET.SubElement(filtering, 'cut_ga')
+        cut_ga.text = str(msf_defaults['cut_ga'])
+
+        tree = ET.ElementTree(model_conf)
+        conf_path = os.path.join(pack_dir, 'model_conf.xml')
+
+        try:
+            ET.indent(model_conf)
+        except AttributeError:
+            # workaround as ET.indent appear in python3.9
+            from macsypy.utils import indent_wrapper
+            ET.indent = indent_wrapper(type(tree))
+            ET.indent(model_conf)
+
+        tree.write(conf_path,
+                   encoding='UTF-8',
+                   xml_declaration=True)
+        if license:
+            # Elementtree API does not allow to insert comment outside the tree (before root node)
+            # this is the reason of this workaround
+            # write the xml, read it as text, insert the comment, and write it again :-(
+
+            with open(conf_path, 'r') as conf_file:
+                conf = conf_file.readlines()
+            license = f"""<!--
+{license}-->
+"""
+            conf.insert(1, license)
+            with open(conf_path, 'w') as conf_file:
+                conf_file.writelines(conf)
+
+
+    ######################
+    # Initialize Package #
+    ######################
+    c_date = time.localtime().tm_year
+    pack_dir = create_package_dir(args.pack_name, models_dir=args.models_dir)
+    def_dir = os.path.join(pack_dir, 'definitions')
+    profiles_dir = os.path.join(pack_dir, 'profiles')
+    license_text = None
+    os.mkdir(def_dir)
+    os.mkdir(profiles_dir)
+
+    if args.holders:
+        add_copyright(pack_dir, args.pack_name, c_date, args.holders, args.desc)
+    else:
+        _log.warning(f"Consider to add copyright to protect your rights.")
+
+    if args.license:
+        try:
+            license_text = licenses.licence(args.license, args.pack_name, args.authors, c_date, args.holders, args.desc)
+        except KeyError:
+            _log.error(f"The license {args.license} is not managed by init (see macsydata init help). "
+                       f"You will have to put the license by hand in package.")
+            license_text=None
+        add_license(pack_dir, license_text)
+    else:
+        _log.warning(f"Consider licensing {args.pack_name} to give the end-user the right to use your package,"
+                     f"and protect your rights. https://data.europa.eu/elearning/en/module4/#/id/co-01")
+
+    add_def_skeleton(license=license_text)
+
+    create_model_conf(pack_dir, license=license_text)
+
+    add_readme(pack_dir, args.pack_name, args.desc)
+
+    add_metadata(pack_dir, args.maintainer, args.email, desc=args.desc, license=args.license,
+                 c_date=c_date, c_holders=args.holders)
+
+    _log.info(f"""The skeleton of {args.pack_name} is ready.
+The package is located at {pack_dir}
+
+- Edit metadata.yml and fill how to cite your package and where to find documentation about it.
+- Add hmm profiles in {pack_dir}/profiles directory
+- A skeleton of model definitions has been added in {pack_dir}/definitions. 
+  For complete documentation about model grammar read https://macsyfinder.readthedocs.io/en/latest/modeler_guide/modeling.html
+- A configuration file has been added (model_conf.xml) with default value tweak this file if needed. 
+  (https://macsyfinder.readthedocs.io/en/latest/modeler_guide/package.html#model-configuration)
+  
+Before to publish your package you can use `macsydata check` to verify it's integrity.
+"""
+              )
+    _log.warning("Read macsyfinder modeler guide for further details: "
+                 "https://macsyfinder.readthedocs.io/en/latest/modeler_guide/index.html")
+
 ##################################
 # parsing command line arguments #
 ##################################
@@ -661,7 +992,7 @@ def build_arg_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(
         epilog="For more details, visit the MacSyFinder website and see the MacSyFinder documentation.",
         formatter_class=argparse.RawDescriptionHelpFormatter,
-        description=dedent(r'''
+        description=textwrap.dedent(r'''
 
          *            *               *                   * *       * 
     *           *               *   *   *  *    **                *  
@@ -753,6 +1084,11 @@ def build_arg_parser() -> argparse.ArgumentParser:
                                    help='Package name.')
     install_subparser.add_argument('--cache',
                                    help=argparse.SUPPRESS)
+    install_subparser.add_argument('--no-clean',
+                                   action='store_true',
+                                   default=False,
+                                   # do not clean cache for debugging purpose ONLY
+                                   help=argparse.SUPPRESS)
     #############
     # Uninstall #
     #############
@@ -819,6 +1155,17 @@ def build_arg_parser() -> argparse.ArgumentParser:
     list_subparser.add_argument('--models-dir',
                                 help='the path of the alternative root directory containing package instead used '
                                      'canonical locations')
+    list_subparser.add_argument('--long', '-l',
+                                action='store_true',
+                                default=False,
+                                help="in addition displays the path where is store each package"
+                                )
+    list_subparser.add_argument('-v',
+                                dest='long',
+                                action='store_true',
+                                default=False,
+                                help="alias for -l/--long option"
+                                )
     ##########
     # freeze #
     ##########
@@ -873,6 +1220,36 @@ def build_arg_parser() -> argparse.ArgumentParser:
     def_subparser.add_argument('--models-dir',
                                help='the path to the alternative root directory containing packages instead to the '
                                     'canonical locations')
+    ########
+    # init #
+    ########
+    init_subparser = subparsers.add_parser('init',
+                                           help='Create a template for a new data package')
+    init_subparser.set_defaults(func=do_init_package)
+    init_subparser.add_argument('--pack-name',
+                                required=True,
+                                help='The name of the data package.')
+    init_subparser.add_argument('--maintainer',
+                                required=True,
+                                help='The name of the package maintainer.')
+    init_subparser.add_argument('--email',
+                                required=True,
+                                help='The email of the package maintainer.')
+    init_subparser.add_argument('--authors',
+                                required=True,
+                                help="The authors of the package. Could be different that the maintainer."
+                                     "Could be several persons. Surround the names by quotes 'John Doe, Richard Miles'")
+    init_subparser.add_argument('--license',
+                                choices=['cc-by', 'cc-by-sa', 'cc-by-nc', 'cc-by-nc-sa', 'cc-by-nc-nd'],
+                                help="""The license under this work will be released.
+if the license you choice is not in the list, you can do it manually
+by adding the license file in package and add suitable headers in model definitions.""")
+    init_subparser.add_argument('--holders',
+                                help="The holders of the copyright")
+    init_subparser.add_argument('--desc',
+                                help="A short description (one line) of the package")
+    init_subparser.add_argument('--models-dir',
+                                help='The path of an alternative models directory by default the package will be created here.' )
     return parser
 
 
