@@ -1,6 +1,6 @@
 #########################################################################
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -36,6 +36,7 @@ import macsypy
 from macsypy.config import MacsyDefaults, Config
 from macsypy.database import Indexes
 from macsypy.hit import get_best_hits
+from macsypy.registries import split_def_name
 
 # _log is set in main func
 _log = None
@@ -506,8 +507,10 @@ def main(args=None, log_level=None) -> None:
 
     hmmer_files = sorted(glob.glob(os.path.join(hmmer_results, f"{parsed_args.pattern}{hmm_suffix}")))
     try:
-        model_familly_name = cfg.models()[0]
+        # models can be a path like TXSScan/bacteria/diderm
+        model_familly_name = split_def_name(cfg.models()[0])[0]
         model_dir = [p for p in [os.path.join(p, model_familly_name) for p in cfg.models_dir()] if os.path.exists(p)][-1]
+
         profiles_dir = os.path.join(model_dir, 'profiles')
     except IndexError:
         _log.critical(f"Cannot find models in conf file {msf_run_path}. "
