@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -157,10 +157,8 @@ class TsvSolutionSerializer:
     Handle Solution (list of Systems) serialization in tsv format
     """
 
-    def __init__(self):
-        """Constructor """
-        __class__.header = 'sol_id\t' + TsvSystemSerializer.header
-        __class__.template = Template(f"$$sol_id\t{TsvSystemSerializer.template.template}")
+    header = 'sol_id\t' + TsvSystemSerializer.header
+    template = Template(f"$$sol_id\t{TsvSystemSerializer.template.template}")
 
 
     def serialize(self, solution, sol_id, hit_system_tracker):
