@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -24,6 +24,7 @@
 
 import os
 import shutil
+import unittest
 from argparse import Namespace
 from configparser import ConfigParser, ParsingError
 import tempfile
@@ -428,7 +429,7 @@ class TestConfig(MacsyTest):
         self.assertEqual(cfg.i_evalue_sel(), 0.012)
         self.assertEqual(cfg.e_value_search(), 0.12)
         self.assertEqual(cfg.coverage_profile(), 0.55)
-        self.assertTrue(cfg.no_cut_ga())
+        self.assertFalse(cfg.cut_ga())
 
 
     def test_bad_values(self):
@@ -508,7 +509,6 @@ class TestConfig(MacsyTest):
         with tempfile.TemporaryDirectory() as tmpdirname:
             cfg_path = os.path.join(tmpdirname, 'macsyfinder.conf')
             cfg.save(path_or_buf=cfg_path)
-            cfg.save(path_or_buf='/tmp/macsyfinder.conf')
             new_args = Namespace()
             new_args.cfg_file = cfg_path
             restored_cfg = Config(self.defaults, new_args)
@@ -561,12 +561,52 @@ class TestConfig(MacsyTest):
         self.assertEqual(str(ctx.exception),
                          f"No config file found in dir {self.parsed_args.previous_run}")
 
-    def test_no_cut_ga(self):
+    def test_cut_ga(self):
+        # default value
         cfg = Config(self.defaults, self.parsed_args)
-        self.assertFalse(cfg.no_cut_ga())
+        self.assertTrue(cfg.cut_ga())
+        # user specify --no-cu-ga
         self.parsed_args.no_cut_ga = True
         cfg = Config(self.defaults, self.parsed_args)
-        self.assertTrue(cfg.no_cut_ga())
+        self.assertFalse(cfg.cut_ga())
+
+        # the user does not specify anything
+        # the modeler set cut-ga false in model_conf
+        self.parsed_args.cut_ga = None
+        self.parsed_args.no_cut_ga = None
+        self.parsed_args.models_dir = self.find_data('models')
+        self.parsed_args.models = ['TFF-SF', 'all']
+        cfg = Config(self.defaults, self.parsed_args)
+        self.assertFalse(cfg.cut_ga())
+
+        # the user specify --cut-ga
+        # the modeler set cut-ga false in model_conf
+        self.parsed_args.cut_ga = True
+        self.parsed_args.no_cut_ga = None
+        self.parsed_args.models_dir = self.find_data('models')
+        self.parsed_args.models = ['TFF-SF', 'all']
+        cfg = Config(self.defaults, self.parsed_args)
+        self.assertTrue(cfg.cut_ga())
+
+    @unittest.skipIf(not shutil.which('hmmsearch'), "'hmmsearch' not found in PATH")
+    def test_hmmsearch(self):
+        cfg = Config(self.defaults, self.parsed_args)
+        self.assertEqual(cfg.hmmer(), shutil.which('hmmsearch'))
+
+    def test_hmmsearch_set_by_user(self):
+        self.parsed_args.hmmer = 'nimportnaoik'
+        cfg = Config(self.defaults, self.parsed_args)
+        self.assertEqual(cfg.hmmer(), self.parsed_args.hmmer)
+
+    def test_no_hmmsearch(self):
+        # if hmmsearch is not found in path the default is set to None (shutil.which('hmmsearch'))
+        self.defaults.hmmer = None
+        with self.assertRaises(ValueError) as ctx:
+            with self.catch_log():
+                Config(self.defaults, self.parsed_args)
+        self.assertEqual(str(ctx.exception),
+                         "'hmmsearch' NOT found in your PATH, Please specify hmmsearch path with --hmmer opt or"
+                         " install 'hmmer' package.")
 
     def test_e_value_search(self):
         cfg = Config(self.defaults, self.parsed_args)
