@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -41,9 +41,9 @@ class TestMacsyDefaults(MacsyTest):
         self.defaults = {'cfg_file': None,
                          'coverage_profile': 0.5,
                          'e_value_search': 0.1,
-                         'no_cut_ga': False,
+                         'cut_ga': True,
                          'db_type': None,
-                         'hmmer': 'hmmsearch',
+                         'hmmer': shutil.which('hmmsearch'),
                          'i_evalue_sel': 0.001,
                          'idx': False,
                          'index_dir': None,
@@ -70,6 +70,8 @@ class TestMacsyDefaults(MacsyTest):
                          'topology_file': None,
                          'verbosity': 0,
                          'worker': 1,
+                         'timeout': 0,
+                         'force_run': False,
                          'mandatory_weight': 1.0,
                          'accessory_weight': .5,
                          'neutral_weight': 0.0,
