@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -30,6 +30,8 @@ import sys
 import tarfile
 import unittest
 import io
+import shlex
+from collections import namedtuple
 
 import macsypy.registries
 from macsypy.registries import scan_models_dir, ModelRegistry
@@ -69,7 +71,7 @@ class TestMacsydata(MacsyTest):
     def tearDown(self):
         macsydata.RemoteModelIndex.remote_exists = self._remote_exists
         try:
-            #shutil.rmtree(self.tmpdir)
+            shutil.rmtree(self.tmpdir)
             pass
         except:
             pass
@@ -240,14 +242,52 @@ copyright: 2019, Institut Pasteur, CNRS"""
         self.args.outdated = False
         self.args.uptodate = False
         self.args.models_dir = None
+        self.args.long = False
         try:
             with self.catch_io(out=True):
                 macsydata.do_list(self.args)
                 packs = sys.stdout.getvalue().strip()
         finally:
             macsydata._find_all_installed_packages = find_all_packages
+        expected_output = "fake_1-0.0b2\nfake_2-0.0b2"
         self.assertEqual(packs,
-                         "fake_1-0.0b2\nfake_2-0.0b2")
+                         expected_output)
+
+
+    def test_list_long(self):
+        fake_packs = ('fake_1', 'fake_2')
+        for name in fake_packs:
+            self.create_fake_package(name, dest=self.models_dir[0])
+        model_dir = self.tmpdir
+        registry = ModelRegistry()
+        for model_loc in scan_models_dir(self.models_dir[0]):
+            registry.add(model_loc)
+
+
+        def fake_find_all_installed_package(models_dir=None):
+            return registry
+
+
+        find_all_packages = macsydata._find_all_installed_packages
+        macsydata._find_all_installed_packages = fake_find_all_installed_package
+
+        self.args.verbose = 1
+        self.args.outdated = False
+        self.args.uptodate = False
+        self.args.models_dir = None
+        self.args.long = True
+
+        try:
+            with self.catch_io(out=True):
+                macsydata.do_list(self.args)
+                packs = sys.stdout.getvalue().strip()
+        finally:
+            macsydata._find_all_installed_packages = find_all_packages
+        expected_output  = f"""fake_1-0.0b2   ({os.path.join(model_dir, 'models', fake_packs[0])})
+fake_2-0.0b2   ({os.path.join(model_dir, 'models', fake_packs[1])})"""
+
+        self.assertEqual(packs,
+                         expected_output)
 
 
     def test_list_outdated(self):
@@ -271,7 +311,7 @@ copyright: 2019, Institut Pasteur, CNRS"""
         self.args.outdated = True
         self.args.uptodate = False
         self.args.models_dir = None
-
+        self.args.long = False
         try:
             with self.catch_io(out=True):
                 macsydata.do_list(self.args)
@@ -279,7 +319,10 @@ copyright: 2019, Institut Pasteur, CNRS"""
         finally:
             macsydata._find_all_installed_packages = find_all_packages
             macsydata.RemoteModelIndex.list_package_vers = remote_list_packages_vers
-        self.assertEqual(packs, 'fake_1-1.0 [0.0b2]')
+
+        expected_output = 'fake_1-1.0 [0.0b2]'
+        self.assertEqual(packs,
+                         expected_output)
 
 
     def test_list_uptodate(self):
@@ -302,6 +345,7 @@ copyright: 2019, Institut Pasteur, CNRS"""
         self.args.outdated = False
         self.args.uptodate = True
         self.args.models_dir = None
+        self.args.long = False
 
         try:
             with self.catch_io(out=True):
@@ -310,7 +354,8 @@ copyright: 2019, Institut Pasteur, CNRS"""
         finally:
             macsydata._find_all_installed_packages = find_all_packages
             macsydata.RemoteModelIndex.list_package_vers = remote_list_packages_vers
-        self.assertEqual(packs, 'fake_2-0.0b2')
+        expected_output = 'fake_2-0.0b2'
+        self.assertEqual(packs, expected_output)
 
 
     def test_list_verbose(self):
@@ -333,6 +378,7 @@ copyright: 2019, Institut Pasteur, CNRS"""
         self.args.outdated = False
         self.args.uptodate = False
         self.args.models_dir = None
+        self.args.long = False
 
         try:
             with self.catch_io(out=True):
@@ -399,9 +445,10 @@ _ bla bla
 
 To cite MacSyFinder:
 
-- Abby SS, Néron B, Ménager H, Touchon M, Rocha EPC (2014)
-  MacSyFinder: A Program to Mine Genomes for Molecular Systems with an Application to CRISPR-Cas Systems.
-  PLoS ONE 9(10): e110726. doi:10.1371/journal.pone.0110726"""
+- Néron, Bertrand; Denise, Rémi; Coluzzi, Charles; Touchon, Marie; Rocha, Eduardo P.C.; Abby, Sophie S. 
+  MacSyFinder v2: Improved modelling and search engine to identify molecular systems in genomes. 
+  Peer Community Journal, Volume 3 (2023), article no. e28. doi : 10.24072/pcjournal.250.
+  https://peercommunityjournal.org/articles/10.24072/pcjournal.250/"""
 
         self.assertEqual(expected_citation, citation)
 
@@ -718,6 +765,7 @@ Available versions: 1.0"""
         self.args.upgrade = False
         self.args.force = False
         self.args.target = macsydata_dest
+        self.args.no_clean = False
 
         macsydata.Config.models_dir = lambda x: self.models_dir
         try:
@@ -756,6 +804,7 @@ Available versions: 1.0"""
         self.args.upgrade = False
         self.args.force = False
         self.args.target = macsydata_target
+        self.args.no_clean = False
 
         with self.catch_log(log_name='macsydata'):
             macsydata.do_install(self.args)
@@ -791,6 +840,7 @@ Available versions: 1.0"""
         self.args.upgrade = False
         self.args.force = False
         self.args.target = macsydata_target
+        self.args.no_clean = False
 
         with self.assertRaises(RuntimeError) as ctx:
             macsydata.do_install(self.args)
@@ -821,6 +871,7 @@ Available versions: 1.0"""
         self.args.upgrade = False
         self.args.force = False
         self.args.target = macsydata_dest
+        self.args.no_clean = False
 
         macsydata.Config.models_dir = lambda x: self.models_dir
         try:
@@ -858,6 +909,7 @@ To force installation use option -f --force-reinstall."""
         self.args.upgrade = False
         self.args.force = False
         self.args.target = macsydata_dest
+        self.args.no_clean = False
 
         macsydata.Config.models_dir = lambda x: self.models_dir
         try:
@@ -904,6 +956,7 @@ The models {pack_name} ({pack_vers}) have been installed successfully."""
         self.args.upgrade = False
         self.args.force = False
         self.args.target = macsydata_dest
+        self.args.no_clean = False
 
         macsydata.Config.models_dir = lambda x: self.models_dir
         try:
@@ -941,6 +994,7 @@ You can fix it by removing '{os.path.join(self.models_dir[0], pack_name)}'."""
         self.args.force = False
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.target = macsydata_dest
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -983,6 +1037,7 @@ You can fix it by removing '{os.path.join(self.models_dir[0], pack_name)}'."""
         self.args.force = False
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.target = None
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1023,6 +1078,7 @@ You can fix it by removing '{os.path.join(self.models_dir[0], pack_name)}'."""
         self.args.force = False
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.target = None
+        self.args.no_clean = False
 
         # function which doing net operations
         # so we need to mock them
@@ -1065,6 +1121,7 @@ To force installation use option -f --force-reinstall.""")
         self.args.force = True
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.target = macsydata_dest
+        self.args.no_clean = False
 
         # function which doing net operations
         # so we need to mock them
@@ -1109,6 +1166,7 @@ To force installation use option -f --force-reinstall.""")
         self.args.force = False
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.target = None
+        self.args.no_clean = False
 
         # function which doing net operations
         # so we need to mock them
@@ -1150,6 +1208,7 @@ To install it please run 'macsydata install --upgrade {pack_name}'""")
         self.args.force = False
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.target = None
+        self.args.no_clean = False
 
         # function which doing net operations
         # so we need to mock them
@@ -1193,6 +1252,7 @@ To downgrade to 0.0b1 use option -f --force-reinstall.""")
         self.args.force = False
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.target = macsydata_dest
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1276,6 +1336,7 @@ Maybe you can use --user option to install in your HOME.""")
         self.args.careful = False
         self.args.match_case = False
         self.args.models_dir = None
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1304,6 +1365,7 @@ Maybe you can use --user option to install in your HOME.""")
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.careful = False
         self.args.match_case = False
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1332,6 +1394,7 @@ Maybe you can use --user option to install in your HOME.""")
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.careful = False
         self.args.match_case = True
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1361,6 +1424,7 @@ Maybe you can use --user option to install in your HOME.""")
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.careful = True
         self.args.match_case = False
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1417,6 +1481,7 @@ Maybe you can use --user option to install in your HOME.""")
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.careful = True
         self.args.match_case = True
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1446,6 +1511,7 @@ Maybe you can use --user option to install in your HOME.""")
         self.args.org = 'macsy-foo-bar'  # to be sure that the network function are mocked
         self.args.careful = True
         self.args.match_case = True
+        self.args.no_clean = False
 
         # functions which do net operations
         # so we need to mock them
@@ -1476,6 +1542,71 @@ Maybe you can use --user option to install in your HOME.""")
             macsydata.RemoteModelIndex.list_package_vers = remote_list_package_vers
 
 
+    def test_init_package_minimal(self):
+        self.args.pack_name = 'minimal_pack'
+        self.args.maintainer = 'John Doe'
+        self.args.email = 'john.doe@domain.org'
+        self.args.authors = 'Jim Doe, John Doe'
+        self.args.license = None
+        self.args.holders = None
+        self.args.desc = None
+        self.args.models_dir = self.models_dir[0]
+        self.args.no_clean = False
+        # see below (test_init_package_complete)
+        # why a do a mock for localtime
+        fake_time = namedtuple('FakeTime', ['tm_year'])
+        local_time_ori = macsydata.time.localtime
+        macsydata.time.localtime = lambda: fake_time(2022)
+        try:
+            with self.catch_log(log_name='macsydata') as log:
+                macsydata.do_init_package(self.args)
+
+            files = ('README.md', 'metadata.yml', 'model_conf.xml', os.path.join('definitions', 'model_example.xml'))
+            for f_name in files:
+                # ElementTree ensure order of attribute only from python3.9
+                if sys.version_info.minor < 9 and f_name.endswith('.xml'):
+                    continue
+                with self.subTest(file_name=f_name):
+                    expected_file = self.find_data(self.args.pack_name, f_name)
+                    got_file = os.path.join(self.args.models_dir, self.args.pack_name, f_name)
+                    self.assertFileEqual(expected_file, got_file)
+        finally:
+            macsydata.time.localtime = local_time_ori
+
+
+    def test_init_package_complete(self):
+        self.args.pack_name = 'complete_pack'
+        self.args.maintainer = 'John Doe'
+        self.args.email = 'john.doe@domain.org'
+        self.args.authors = 'Jim Doe, John Doe'
+        self.args.license = 'cc-by-nc-sa'
+        self.args.holders = 'Pasteur'
+        self.args.desc = 'description in one line of this package'
+        self.args.models_dir = self.models_dir[0]
+        self.args.no_clean = False
+        # do_init_package call localtime to get year
+        # and put it in copyright filed of metadata
+        # so I do monkey patching to get reliable year
+        # otherwise I have to adapt the test each new year ;-(
+        fake_time = namedtuple('FakeTime', ['tm_year'])
+        local_time_ori = macsydata.time.localtime
+        macsydata.time.localtime = lambda: fake_time(2022)
+        try:
+            with self.catch_log(log_name='macsydata') as log:
+                macsydata.do_init_package(self.args)
+
+            files = ('README.md', 'metadata.yml', 'model_conf.xml', os.path.join('definitions', 'model_example.xml'))
+            for f_name in files:
+                # ElementTree ensure order of attribute only from python3.9
+                if sys.version_info.minor < 9 and f_name.endswith('.xml'):
+                    continue
+                with self.subTest(file_name=f_name):
+                    expected_file = self.find_data(self.args.pack_name, f_name)
+                    got_file = os.path.join(self.args.models_dir, self.args.pack_name, f_name)
+                    self.assertFileEqual(expected_file, got_file)
+        finally:
+            macsydata.time.localtime = local_time_ori
+
     def test_build_argparser(self):
         parser = macsydata.build_arg_parser()
         cmd = "macsydata install toto>1"
@@ -1528,6 +1659,15 @@ Maybe you can use --user option to install in your HOME.""")
         args = parser.parse_args(cmd.split()[1:])
         self.assertEqual(args.func.__name__, 'do_available')
 
+        cmd = "macsydata init --pack-name foo --authors 'john Doe' --maintainer 'Jim Doe' " \
+              "--email 'jim.doe@my_domain.com'"
+        args = parser.parse_args(shlex.split(cmd)[1:])
+        self.assertEqual(args.func.__name__, 'do_init_package')
+        self.assertEqual(args.pack_name, 'foo')
+        self.assertEqual(args.authors, 'john Doe')
+        self.assertEqual(args.maintainer, 'Jim Doe')
+        self.assertEqual(args.email, 'jim.doe@my_domain.com')
+
     def test_cmd_name(self):
         parser = macsydata.build_arg_parser()
         cmd = "macsydata download foo"
