@@ -2,7 +2,7 @@
 # MacSyFinder - Detection of macromolecular systems in protein dataset  #
 #               using systems modelling and similarity search.          #
 # Authors: Sophie Abby, Bertrand Neron                                  #
-# Copyright (c) 2014-2022  Institut Pasteur (Paris) and CNRS.           #
+# Copyright (c) 2014-2023  Institut Pasteur (Paris) and CNRS.           #
 # See the COPYRIGHT file for details                                    #
 #                                                                       #
 # This file is part of MacSyFinder package.                             #
@@ -27,9 +27,10 @@ import shutil
 import tempfile
 import argparse
 
-from macsypy.config import Config, MacsyDefaults
 from macsypy.registries import ModelRegistry, scan_models_dir
-from macsypy.utils import get_def_to_detect, get_replicon_names, threads_available
+from macsypy.utils import get_def_to_detect, get_replicon_names, threads_available, parse_time
+from macsypy.error import MacsypyError
+
 from tests import MacsyTest
 
 
@@ -75,12 +76,27 @@ class TestUtils(MacsyTest):
             get_def_to_detect(('set_1', ['FOO', 'BAR']), registry)
 
 
-    def test_get_replicon_names(self):
-        replicon_names = get_replicon_names(self.find_data('base', 'gembase.fasta'))
+    def test_get_replicon_names_gembase(self):
+        replicon_names = get_replicon_names(self.find_data('base', 'gembase.fasta'), 'gembase')
         self.assertListEqual(replicon_names,
                              ['GCF_000005845', 'GCF_000006725', 'GCF_000006745', 'GCF_000006765', 'GCF_000006845',
                               'GCF_000006905', 'GCF_000006925', 'GCF_000006945'])
 
+    def test_get_replicon_names_ordered(self):
+        replicon_names = get_replicon_names(self.find_data('base', 'MOBP1_once.prt'), 'ordered_replicon')
+        self.assertListEqual(replicon_names,
+                             ['MOBP1_once'])
+
+    def test_get_replicon_names_unordered(self):
+        replicon_names = get_replicon_names(self.find_data('base', 'MOBP1_once.prt'), 'unordered')
+        self.assertListEqual(replicon_names,
+                             ['MOBP1_once'])
+
+    def test_get_replicon_names_bad_type(self):
+        with self.assertRaises(MacsypyError) as ctx:
+            get_replicon_names(self.find_data('base', 'MOBP1_once.prt'), 'bad_dbtype')
+        self.assertEqual(str(ctx.exception),
+                         'Invalid genome type: bad_dbtype')
 
     def test_threads_available(self):
         if hasattr(os, "sched_getaffinity"):
@@ -104,4 +120,18 @@ class TestUtils(MacsyTest):
             if sched_getaffinity_ori:
                 os.sched_getaffinity = sched_getaffinity_ori
             else:
-                del os.sched_getaffinity
\ No newline at end of file
+                del os.sched_getaffinity
+
+    def test_parse_time(self):
+        self.assertEqual(parse_time(10), 10)
+        self.assertEqual(parse_time('10s'), 10)
+        self.assertEqual(parse_time('10m'), 600)
+        self.assertEqual(parse_time('1h'), 3600)
+        self.assertEqual(parse_time('1d'), 86400)
+        self.assertEqual(parse_time(10.5), 10)
+        self.assertEqual(parse_time('10m10s1h'), 600 + 10 + 3600)
+        self.assertEqual(parse_time('10m 10s 1h'), 600 + 10 + 3600)
+        with self.assertRaises(ValueError) as ctx:
+            parse_time('10W')
+        self.assertEqual(str(ctx.exception),
+                         'Not valid time format. Units allowed h/m/s.')
